labeltools.label_leaves_in_expr_with_written_leaf_duration
==========================================================

.. autofunction:: abjad.tools.labeltools.label_leaves_in_expr_with_written_leaf_duration.label_leaves_in_expr_with_written_leaf_duration
